# coding: utf-8

"""
    Tests API

    This API allows you to list, create, edit, and delete Network and Application Synthetics tests. 

    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class TestIpv6Policy(str, Enum):
    """
    IP version policy. Overrides the IPv6 policy configured at the agent level.
    """

    """
    allowed enum values
    """
    FORCE_MINUS_IPV4 = 'force-ipv4'
    PREFER_MINUS_IPV6 = 'prefer-ipv6'
    FORCE_MINUS_IPV6 = 'force-ipv6'
    USE_MINUS_AGENT_MINUS_POLICY = 'use-agent-policy'
    UNKNOWN = 'unknown'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of TestIpv6Policy from a JSON string"""
        return cls(json.loads(json_str))

    @classmethod
    def _missing_(cls, value):
        """Handle unknown values"""
        return cls.UNKNOWN

